"use strict";var i=function(c,r){return function(){return r||c((r={exports:{}}).exports,r),r.exports}};var t=i(function(a,e){
var s=require("process");function u(){return s.cwd()}e.exports=u
});var n=t();module.exports=n;
/** @license Apache-2.0 */
//# sourceMappingURL=index.js.map
